@@ -9,9 +9,9 @@ my $orig = $ARGV[0];
 die "Original file $orig not found\n" unless(-e $orig);
 my %layouts;
 
-while(<*.layout>) {
-	/^(.+)\.layout$/;
-	$layouts{$1} = "$1.layout";
+while(<*.conf>) {
+	/^(.+)\.conf$/;
+	$layouts{$1} = "$1.conf";
 }
 
 open(OUT, ">$symbols") or die "Can't create file $symbols\n";
@@ -38,7 +38,7 @@ while(<IN>) {
 		print OUT;
 	} else {
 #		next unless($_);
-		($_) = split/\#/;
+		($_) = split/\/\//;
 		next if(!$_ || /^\s*$/);
 		while(/\{/) { s/\{//; $mode++; }
 		while(/\}/) { s/\}//; $mode--; }
